@@ -22,7 +22,7 @@ def Generate_Command(Control_ID: str, Group: str, Command: str, bible, Data: int
         temp_command += str(i).zfill(2)
     Full_command = temp_command + Generate_Checksum(temp_command)
     log.debug("Command: %s", Full_command)
-    Decode_Hex(Full_command, bible, "command")
+    #Decode_Hex(Full_command, bible, "command")
     return Full_command
 
 def Decode_Hex(Hex, bible, Hex_type="response"):
