@@ -23,8 +23,11 @@ class serial_device:
         host = self.ip
         port = self.port
         log.info("Connecting to %s on port %s", host, port)
-        log.warning(self.connection.connect_ex((host, port)))
-        log.info("Potentially connected")
+        try:
+            self.connection.connect((host, port))
+            log.info("Connected")
+        except:
+            log.warning("Connection failed")
 
     def disconnect(self):
         log.info("Disconnecting")
